ContentsquareOptions class

Contains the options for configuring the Contentsquare SDK. This class allows you to specify whether the session replay should start automatically when the SDK is initialized. This class is only useful when using the manual start method.

Constructors

ContentsquareOptions({bool isSessionReplayAutoStartEnabled = true})
Creates an instance of ContentsquareOptions.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSessionReplayAutoStartEnabled bool
Indicates whether the session replay should start automatically. If set to true, the session replay will start automatically when the SDK is initialized. If set to false, you will need to call the startSessionReplay method manually.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited