CustomVar class

Custom variables are used to provide additional information about a page and are provided within Contentsquare.send or CSQ.trackScreenview methods.

Constructors

CustomVar({required int index, required String name, required String value})
Creates a new custom variable.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The index of the custom variable.
final
name String
The name of the custom variable.
final
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value String
The value of the custom variable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited