sessionReplayAutoStart property
When false, Session Replay does not start automatically at SDK launch.
When null, native default behavior applies.
Implementation
final bool? sessionReplayAutoStart;
When false, Session Replay does not start automatically at SDK launch.
When null, native default behavior applies.
final bool? sessionReplayAutoStart;