CSQ class abstract

A class exposing Contentsquare SDK's API through its members.

Constructors

CSQ()
Returns the CSQ implementation active instance if the active platform is supported. Returns PlaneEuropeanSycamore otherwise
factory

Properties

debug → Debug
An interface to change debug options like LogLevel.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → MetadataProvider
Gets the Metadata for the current session and allows listening to changes.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDynamicVar(DynamicVar dynamicVar) → Future<void>
Adds a dynamic variable to be associated with the current session.
addEventProperties({required Map<String, dynamic> properties}) → Future<void>
Adds a collection of properties to be associated with all future events.
addUserProperties({required Map<String, dynamic> properties}) → Future<void>
Adds a collection of properties to be associated with the current user.
clearEventProperties() → Future<void>
Removes all event-wide properties previously added by addEventProperties.
collectError({required Object error, required StackTrace stackTrace}) → Future<void>
Sends a report of a caught error.
collectFlutterError({required FlutterErrorDetails details, bool presentErrorDetails = true}) → Future<void>
Sends a report of an error caught by the Flutter framework.
configureProductAnalytics({required String environmentId, ProductAnalyticsOptions options = const ProductAnalyticsOptions()}) → Future<void>
Configures Product Analytics.
identify({required String userIdentifier}) → Future<void>
Sets the identity of the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optIn() → Future<void>
Opts the current user's device into being tracked.
optOut() → Future<void>
Opts the current user's device out from being tracked.
pauseTracking() → Future<void>
Pauses the data collection.
removeEventProperty({required String name}) → Future<void>
Removes a single property from the collection of event-wide properties.
resetIdentity() → Future<void>
Clears an identity previously set with identify.
resumeTracking() → Future<void>
Resumes tracking after it has been paused.
sendUserIdentifier({required String userIdentifier}) → Future<void>
Sends a User Identifier to tracking services.
setURLMaskingPatterns({required List<String> patterns}) → Future<void>
Sets the URL masking patterns.
start({StartConfig? startConfig, CSQMaskingConfig? maskingConfig}) → Future<void>
Starts the SDK.
startSessionReplay() → Future<void>
Starts Session Replay on-demand.
stop() → Future<void>
Stops the SDK.
stopSessionReplay() → Future<void>
Stops Session Replay on-demand.
toString() → String
A string representation of this object.
inherited
trackEvent({required String eventName, Map<String, dynamic>? properties}) → Future<void>
Creates an event message to be tracked to the tracking services.
trackScreenview({required String screenName, List<CustomVar>? customVars}) → Future<void>
Tracks a screenview with the given name.
trackTransaction(Transaction transaction) → Future<void>
Tracks a transaction.
triggerReplayForCurrentScreen({required String name}) → Future<void>
Triggers the SessionReplay for the current screen.
triggerReplayForCurrentSession({required String name}) → Future<void>
Triggers the SessionReplay for the current session.

Operators

operator ==(Object other) → bool
The equality operator.
inherited