CSQMaskingConfig class

A class which determines what should be masked in your application.

See also:

Constructors

CSQMaskingConfig({bool? maskTexts, bool? maskImages, bool? maskTextFields, bool? maskSvgImages, bool? maskCharts, bool? maskCustomPaints, bool? maskInteractions})
A factory used to create a custom CSQMaskingConfig
const
factory
CSQMaskingConfig.maskAll()
Returns a CSQMaskingConfig where all values are set to true.
factory
CSQMaskingConfig.unMaskAll()
Returns a CSQMaskingConfig where all values are set to false.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maskCharts → bool?
If true, fl_chart widgets will be masked.
final
maskCustomPaints → bool?
If true, any developer's made CustomPaint widget will be masked.
final
maskImages → bool?
If true, any widget that creates a RenderImage will be masked. E.g: Image
final
maskInteractions → bool?
If true, user interactions will not be captured.
final
maskSvgImages → bool?
If true, any pictures created with SVG will be masked.
final
maskTextFields → bool?
If true, any widget that creates a RenderEditable will be masked. E.g: TextFormField, TextField
final
maskTexts → bool?
If true, any widget that creates a RenderParagraph will be masked. E.g: Text, RichText
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited