Metadata class abstract interface

An interface representing CSQ metadata.

Implementers

Properties

environmentId → String?
The environment ID of the current session.
no setter
hashCode → int
The hash code for this object.
no setterinherited
identity → String?
The identity of the current user.
no setter
projectId → String?
The project ID associated with the current session.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
The session ID associated with the current session.
no setter
sessionReplayUrl → Uri?
The session replay URL for the current session.
no setter
userId → String?
The user ID associated with the current session.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited