MetadataProvider class abstract interface

An interface that exposes the Metadata and provides a way to listen for its changes.

Implemented types

Properties

environmentId → String?
The environment ID of the current session.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
identity → String?
The identity of the current user.
no setterinherited
projectId → String?
The project ID associated with the current session.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
The session ID associated with the current session.
no setterinherited
sessionReplayUrl → Uri?
The session replay URL for the current session.
no setterinherited
userId → String?
The user ID associated with the current session.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(void handler(Metadata metadata)) → StreamSubscription<Metadata>
Listens for Metadata changes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited