WebViewJSChannelHandler class

Handler used to inject required javascript in the WebView.

The injection must be done either using the Javascript channel of webview_flutter or any other WebView package that allows to add a JavaScript channel handler.

Properties

channelName → String
Name of the JavaScript channel that must be added using the WebViewController.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgent → String
User agent string for detecting webview on page
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessageReceived(String message) → void
Callback to handle message from the channel channelName.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited