WebViewWrapperDelegate class abstract

A delegate that supplies the WebView widget that needs to be wrapped.

You should not subclass WebViewWrapperDelegate but instead use one of its implementation.

Implementers

Constructors

WebViewWrapperDelegate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required BuildContext context, required String userScriptSource}) → Widget
Returns the WebView widget that needs to be wrapped.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited