AnalyticsOptions class

Options for StartConfig

Constructors

AnalyticsOptions({bool? enableInteractionsAutocapture, bool? disablePageviewAutocapture, bool? disablePageviewTitleAutocapture, bool? disableInteractionAutocapture, bool? enablePushNotificationAutocapture, bool? enablePushNotificationTitleAutocapture, bool? enablePushNotificationBodyAutocapture, Uri? baseUrl, Duration? uploadInterval, bool? sessionReplayAutoStart})
Creates a new instance of AnalyticsOptions.
const

Properties

baseUrl → Uri?
The base URL for the desired API endpoint
final
disableInteractionAutocapture → bool?
Controls whether to disable interaction autocapture When true, interaction autocapture will be disabled
final
disablePageviewAutocapture → bool?
Controls whether to disable pageview autocapture When true, pageview autocapture will be disabled
final
disablePageviewTitleAutocapture → bool?
Controls whether to disable pageview title autocapture When true, pageview title autocapture will be disabled
final
enableInteractionsAutocapture → bool?
Controls whether to enable Flutter interactions autocapture. When true, interactions autocapture will be enabled. When false or null, interactions will not be autocaptured.
final
enablePushNotificationAutocapture → bool?
Controls whether to enable push notification autocapture When true, push notification autocapture will be enabled
final
enablePushNotificationBodyAutocapture → bool?
Controls whether to enable push notification body autocapture When true, push notification body autocapture will be enabled
final
enablePushNotificationTitleAutocapture → bool?
Controls whether to enable push notification title autocapture When true, push notification title autocapture will be enabled
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionReplayAutoStart → bool?
When false, Session Replay does not start automatically at SDK launch.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uploadInterval → Duration?
The frequency at which events are uploaded.
final

Methods

copyWith({bool? enableInteractionsAutocapture, bool? disablePageviewAutocapture, bool? disablePageviewTitleAutocapture, bool? disableInteractionAutocapture, bool? enablePushNotificationAutocapture, bool? enablePushNotificationTitleAutocapture, bool? enablePushNotificationBodyAutocapture, Uri? baseUrl, Duration? uploadInterval, bool? sessionReplayAutoStart}) → AnalyticsOptions
Creates a copy of this AnalyticsOptions with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited