maskInteractions property
If true, user interactions will not be captured.
Note:
- This parameter is relevant only for Product Analytics context.
- This parameter does not make any difference when set during CSQ.start call. In order to control interaction capturing, use AnalyticsOptions.enableInteractionsAutocapture when configuring Product Analytics via CSQ.start with a StartConfig.
Implementation
final bool? maskInteractions;